==> emodpy_measles-0.0.28-py3-none-any.whl: emodpy_measles/interventions/measles_vaccine.py <==
from emod_api import schema_to_class as s2c
import emod_api.campaign as camp

schema_path = None
iv_name = "MCV1"
#dupe_policy = "Replace" # or "Add" or "Abort" -- from covid branch
# Note that duration (what we call waning profile) needs to be configurable, but in an intuitive way

def _SimpleMCV( timestep, coverage=1.0, AgeAtVaccInDays=1, mv_name=iv_name ):
    """
    MCV1 Campaign
    :param Coverage: Demographic Coverage
    :param AgeAtVaccIInDays: Delay period constant for intervention

    Note Start_Day is initialized as 1, recommend that this be aligned with the start of the simulation
    """
    # First, get the objects
    event = s2c.get_class_with_defaults( "CampaignEvent", schema_path )
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator", schema_path )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return ""

    intervention = s2c.get_class_with_defaults( "Vaccine", schema_path )
    efficacy_profile = "WaningEffectConstant"
    waning = s2c.get_class_with_defaults( efficacy_profile, schema_path )
    waning.Initial_Effect = 0.999

    meta_meta_intervention = s2c.get_class_with_defaults( "DelayedIntervention", schema_path )
    meta_meta_intervention.Actual_IndividualIntervention_Configs = [ intervention ]
    meta_meta_intervention.Delay_Period_Distribution="CONSTANT_DISTRIBUTION"
    meta_meta_intervention.Delay_Period_Constant=AgeAtVaccInDays

    meta_intervention = s2c.get_class_with_defaults( "NodeLevelHealthTriggeredIV", schema_path )
    meta_intervention.Demographic_Coverage=coverage
    meta_intervention.Duration=-1
    meta_intervention.Trigger_Condition_List=['Births']
    meta_intervention.Actual_IndividualIntervention_Config = meta_meta_intervention

    # Second, hook them up
    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = meta_meta_intervention
    intervention.Acquire_Config = waning 
    event.Start_Day = float(timestep+1)

    # Third, do the actual settings
    intervention.Intervention_Name = mv_name

    event["Name"] = "MCV1" # ???

    return event

def SimpleMCV1( timestep, coverage=1.0 ):
    return _SimpleMCV( timestep, coverage, AgeAtVaccInDays=270, mv_name="MCV1" )

def SimpleMCV2( timestep, coverage=1.0 ):
    return _SimpleMCV( timestep, coverage, AgeAtVaccInDays=475, mv_name="MCV2" )

def new_intervention_as_file( timestep, filename=None ):
    camp.add( new_intervention( timestep, iv_name ) )
    if filename is None:
        filename = "measles_vaccine.json"
    camp.save( filename )
    return filename

==> emodpy_measles-0.0.30-py3-none-any.whl: emodpy_measles/interventions/measles_vaccine.py <==
from emod_api import schema_to_class as s2c

schema_path = None
iv_name = "MCV1"
#dupe_policy = "Replace" # or "Add" or "Abort" -- from covid branch
# Note that duration (what we call waning profile) needs to be configurable, but in an intuitive way

def _SimpleMCV( timestep, coverage=1.0, AgeAtVaccInDays=1, mv_name=iv_name ):
    """
    MCV1 Campaign
    :param Coverage: Demographic Coverage
    :param AgeAtVaccIInDays: Delay period constant for intervention

    Note Start_Day is initialized as 1, recommend that this be aligned with the start of the simulation
    """
    # First, get the objects
    event = s2c.get_class_with_defaults( "CampaignEvent", schema_path )
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator", schema_path )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return ""

    intervention = s2c.get_class_with_defaults( "Vaccine", schema_path )
    efficacy_profile = "WaningEffectConstant"
    waning = s2c.get_class_with_defaults( efficacy_profile, schema_path )
    waning.Initial_Effect = 0.999

    meta_meta_intervention = s2c.get_class_with_defaults( "DelayedIntervention", schema_path )
    meta_meta_intervention.Actual_IndividualIntervention_Configs = [ intervention ]
    meta_meta_intervention.Delay_Period_Distribution="CONSTANT_DISTRIBUTION"
    meta_meta_intervention.Delay_Period_Constant=AgeAtVaccInDays

    meta_intervention = s2c.get_class_with_defaults( "NodeLevelHealthTriggeredIV", schema_path )
    meta_intervention.Demographic_Coverage=coverage
    meta_intervention.Duration=-1
    meta_intervention.Trigger_Condition_List=['Births']
    meta_intervention.Actual_IndividualIntervention_Config = meta_meta_intervention

    # Second, hook them up
    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = meta_meta_intervention
    intervention.Acquire_Config = waning 
    event.Start_Day = float(timestep+1)

    # Third, do the actual settings
    intervention.Intervention_Name = mv_name

    event["Name"] = "MCV1" # ???

    return event

def SimpleMCV1( camp, timestep, coverage=1.0 ):
    if camp is not None:
        global schema_path
        schema_path = camp.schema_path
    return _SimpleMCV( timestep, coverage, AgeAtVaccInDays=270, mv_name="MCV1" )

def SimpleMCV2( camp, timestep, coverage=1.0 ):
    if camp is not None:
        global schema_path
        schema_path = camp.schema_path
    return _SimpleMCV( timestep, coverage, AgeAtVaccInDays=475, mv_name="MCV2" )

def new_intervention_as_file( camp, timestep, filename=None ):
    camp.add( _SimpleMCV( timestep ) )
    if filename is None:
        filename = "measles_vaccine.json"
    camp.save( filename )
    return filename
